class TSSOP:
    def __init__(self, pin_count=None, A=None, A1=None, b=None, c=None, D=None, D2=None, E=None, E1=None, E2=None,
                 e=None, L=None):
        self.pin_count = pin_count
        self.A = A
        self.A1 = A1
        self.b = b
        self.c = c
        self.D = D
        self.D2 = D2
        self.E = E
        self.E1 = E1
        self.E2 = E2
        self.e = e
        self.L = L
